@@ -2,7 +2,7 @@
 
 require_once('Composer/Autoload/ClassLoader.php');
 include_once('/usr/share/php/HTMLPurifier.composer.php');
-include_once('/usr/share/php/Illuminate/Support/helpers.php');
+include_once('/usr/share/php/Illuminate/Database/autoload.php');
 include_once('/usr/share/php/GuzzleHttp/Psr7/functions_include.php');
 include_once('/usr/share/php/React/Promise/functions_include.php');
 include_once('/usr/share/php/React/Promise/Stream/functions_include.php');
